<?php

/**
 * 设置内容的宽度。
 */
if ( ! isset( $content_width ) )
	$content_width = 600;

/**
 * 启动 falla_setup() 
 */
add_action( 'after_setup_theme', 'falla_setup' );

if ( ! function_exists( 'falla_setup' ) ):
/**
 * 设置主题的默认值并支持WordPress内嵌功能。
**/
function falla_setup() {

	// 加入翻译.
	load_theme_textdomain( 'falla', TEMPLATEPATH . '/languages' );

	$locale = get_locale();
	$locale_file = TEMPLATEPATH . "/languages/$locale.php";
	if ( is_readable( $locale_file ) )
		require_once( $locale_file );

	// 顶部rss 
	add_theme_support( 'automatic-feed-links' );

	// 1个自定义菜单
	register_nav_menu( 'primary', __( 'Primary Menu', 'falla' ) );

}
 
 
endif; //end of falla_setup

/**
 * 设置摘要长度。
 */
function falla_excerpt_length( $length ) {
	return 60;
}
add_filter( 'excerpt_length', 'falla_excerpt_length' );


/**
 * 自定义菜单时可以拖入home链接.
 */
function falla_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'falla_page_menu_args' );

/**
 * 边栏小工具 
 *
 */
function falla_widgets_init() {

	register_sidebar( array(
		'name' => __( 'Main Sidebar', 'falla' ),
		'id' => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
}
add_action( 'widgets_init', 'falla_widgets_init' );


if ( ! function_exists( 'falla_comment' ) ) :
/**
 *评论模板
 *
 *  
 */
function falla_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
/**
楼层
 */
global $commentcount;
 if(!$commentcount) {
  $page = get_query_var('cpage')-1; if ($page<0) $page = 0;
  $cpp=get_option('comments_per_page');
  $commentcount = $cpp * $page;
 }/**楼层结束 */
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
<li class="post pingback">
  <p>
    <?php _e( 'Pingback:', 'falla' ); ?>
    <?php comment_author_link(); ?>
    <?php edit_comment_link( __( 'Edit', 'falla' ), '<span class="edit-link">', '</span>' ); ?>
  </p>
  <?php
			break;
		default :
	?>
<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
  <article id="comment-<?php comment_ID(); ?>" class="comment">
    <footer class="comment-meta">
      <div class="comment-author vcard">
        <?php
						$avatar_size = 68;
						if ( '0' != $comment->comment_parent )
							$avatar_size = 39;

						echo get_avatar( $comment, $avatar_size );

						/* 注释: 1: 评论作者, 2: 日期和时间 */
						printf( __( '%1$s on %2$s <span class="says">said:</span>', 'falla' ),
							sprintf( '<span class="fn">%s</span>', get_comment_author_link() ),
							sprintf( '<a href="%1$s"><time pubdate datetime="%2$s">%3$s</time></a>',
								esc_url( get_comment_link( $comment->comment_ID ) ),
								get_comment_time( 'c' ),
								/* 注释: 1: 日期, 2: 时间 */
								sprintf( __( '%1$s at %2$s', 'falla' ), get_comment_date(), get_comment_time() )
							)
						);
					?>
        <?php edit_comment_link( __( 'Edit', 'falla' ), '<span class="edit-link">', '</span>' ); ?>
      </div>
      <!-- .comment-author .vcard -->
      
      <?php if ( $comment->comment_approved == '0' ) : ?>
      <em class="comment-awaiting-moderation">
      <?php _e( 'Your comment is awaiting moderation.', 'falla' ); ?>
      </em> <br />
      <?php endif; ?>
    </footer>
    <div class="comment-content">
      <?php comment_text(); ?>
    </div>
    <div class="reply">
      <?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply <span>&darr;</span>', 'falla' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
    </div>
    <!-- .reply -->
<!-- 楼层2 -->
 <div style="position: absolute;top: 80px;right: 32px;color: #999;">
<?php if(!$parent_id = $comment->comment_parent) {printf('%1$s楼', ++$commentcount);} ?>
</div>
<!-- 楼层2结束 -->
  </article>
  <!-- #comment-## -->
  
  <?php
			break;
	endswitch;
}
endif; // ends check for falla_comment()


$size = 500; // 500是显示的字节数，可按照自己的要求修改
$more_link_text = 'read more...'; // 显示在摘要后面的提示

add_action('the_content', 'control_content_size');

function control_content_size($content) {
global $size, $more_link_text;
if (is_singular()) return $content;
$content = strip_tags($content);
$content = cut_str($content, $size);
$content = '<p>' . $content . '</p><p><a href="' . get_permalink() . "\" class=\"more-link\">$more_link_text</a></p>";
return $content;
}


/**
* cut_str用于截断包含中文（或其他多字节？）的utf8编码的字符串
* @param string $str utf8编码的字符串
* @param int $len 需要截取的长度（单位是字节）
*/
function cut_str($str, $len) {
if (!isset($str[$len])) {
// 判断字符串长度是否已经达到需要截取的长度
// 未达到时，直接输出原字符串
} else {
if (seems_utf8($str[$len-1])) // 判断截断字符串的最后一个字符是否是utf8编码的
$str = substr($str, 0, $len); // 如果是utf8编码的，直接截断输出
else { // 如果不是utf8编码的，因为utf8编码的中文是三个字节进行保存的，则判断该字符和周围字符组成的字符串是否符合utf8编码
if(seems_utf8($str[$len-3].$str[$len-2].$str[$len-1]))
$str = substr($str, 0, $len-3) . $str[$len-3] . $str[$len-2] . $str[$len-1];

elseif(seems_utf8($str[$len-2].$str[$len-1].$str[$len]))
$str = substr($str, 0, $len-2) . $str[$len-2].$str[$len-1].$str[$len];

elseif(seems_utf8($str[$len-1].$str[$len].$str[$len+1]))
$str = substr($str, 0, $len-1) . $str[$len-1].$str[$len].$str[$len+1];

else // 这个else应该不用也是可以的
$str = substr($str, 0, $len);
}
}
return $str;
}
 
add_filter('the_excerpt', 'excerpt_force_balance_tags'); 
function excerpt_force_balance_tags ($output) { 
    return $output = force_balance_tags($output);; 
} 

/* Pagenavi */  
function pagenavi( $before = '', $after = '', $p = 2 ) {   
if ( is_singular() ) return;   
global $wp_query, $paged;   
$max_page = $wp_query->max_num_pages;   
if ( $max_page == 1 ) return;   
if ( empty( $paged ) ) $paged = 1;   
echo $before.'<div id="pagenavi">'."\n";   
echo '<span class="pages">Page: ' . $paged . ' of ' . $max_page . ' </span>';   
if ( $paged > 1 ) p_link( $paged - 1, 'Previous Page', '«' );   
if ( $paged > $p + 1 ) p_link( 1, 'First Page' );   
if ( $paged > $p + 2 ) echo '... ';   
for( $i = $paged - $p; $i <= $paged + $p; $i++ ) {   
if ( $i > 0 && $i <= $max_page ) $i == $paged ? print "<span class='page-numbers current'>{$i}</span>" : p_link( $i );   
}   
if ( $paged < $max_page - $p - 1 ) echo '... ';   
if ( $paged < $max_page - $p ) p_link( $max_page, 'Last Page' );   
if ( $paged < $max_page ) p_link( $paged + 1,'Next Page', '»' );   
echo '</div>'.$after."\n";   
}   
function p_link( $i, $title = '', $linktype = '' ) {   
if ( $title == '' ) $title = "Page {$i}";   
if ( $linktype == '' ) { $linktext = $i; } else { $linktext = $linktype; }   
echo "<a class='page-numbers' href='", esc_html( get_pagenum_link( $i ) ), "' title='{$title}'>{$linktext}</a>";   
} 
/* 评论表情 */ 
 function wp_smilies() {
    global $wpsmiliestrans;
    if ( !get_option('use_smilies') or (empty($wpsmiliestrans))) return;
    $smilies = array_unique($wpsmiliestrans);
    $link='';
    foreach ($smilies as $key => $smile) {
        $file = get_bloginfo('wpurl').'/wp-includes/images/smilies/'.$smile;
        $value = " ".$key." ";
        $img = "<img src=\"{$file}\" alt=\"{$smile}\" />";
        $imglink = htmlspecialchars($img);
        $link .= "<a href=\"#commentform\" title=\"{$smile}\" onclick=\"document.getElementById('comment').value += '{$value}'\">{$img}</a>&nbsp;";
    }
    echo '<div class="wp_smilies">'.$link.'</div>';
}
?>